/**************************************************************************
 *
 *  File        :  pcm812.h
 *
 *  Description :  phyCORE-ADuC812 Rom-monitor definition.
 *
 *  Version     :  1.1
 *
 *  Copyright 2003 Altium BV
 *
 **************************************************************************/

#ifndef _PCM812_H	
#define _PCM812_H	

#include "phytec.h"	

/* ADuC812 characteristics */	
#define HAS_IEN1	
#define IEN1 IE2

/* Board characteristics */	
#define PHYTEC_MMU_INIT	
#define COPY_SERIAL_VECTOR	

#include "data.h"	

/********************************************************************************		
 *
 *	FUNCTION: ta_init 
 *
 *	DESCRIPTION:
 *         Initialize target specific SFR's
 *
 ********************************************************************************/


_inline void	
ta_init(void)	
{	
	IEN1     =    0;            /* Disable IEN1=IE2 interrupts                  */
	saveIEN1 =    0;            /* Clear saveIEN1                               */
	phytec_mmu_init();          /* Initialize Phytec MMU                        */
	P3       = 0xEF;            /* LED D3 = ON                                  */
}		

/********************************************************************************		
 *
 *	FUNCTION: ta_serial_init
 *
 *	DESCRIPTION:
 *          Initialize the serial port, 19200 baud at 11.0592 MHz.
 * 
 ********************************************************************************/
_inline void		
ta_serial_init(void)		
{		
	SCON     = 0x52;            /* Mode 1,Receive Enable,TI=1              		*/
	IP       = 0x10;            /* Serial interrupt priority = highest (1) 		*/
	TMOD     = 0x20;            /* Timer 1 mode 2 / 8-bit auto-reload      		*/
	TH1      = 0xFD;            /* Timer 1 reload value @ 9600 Bd          		*/
	PCON     = 0x80;            /* Double Baudrate (19200 Bd)              		*/
	TR1      = 0x01;            /* Enable Timer 1                          		*/
	IE       = 0x90;            /* Enable serial interrupt and EA          		*/
}		

/********************************************************************************		
 *
 *	FUNCTION: ta_restore_SFRs
 *
 *	DESCRIPTION:
 *         Restore SFRs to the user program value, when restoring the interrupt
 *         enable registers ensure that the serial interrupt is enabled, however
 *         do not set the global enable flag yet.
 *
 ********************************************************************************/
_inline void		
ta_restore_SFRs( void )		
{						   
   	IE= (saveIE |0x10) & 0x7F;  /* Restore IE ,Set serial interrupt,disable EA 	*/
	IEN1=  saveIEN1;            /* Restore IEN1 					*/
}		

/********************************************************************************	
 *
 *	FUNCTION: ta_save_SFRs
 *
 *	DESCRIPTION:
 *          Save SFRs of the user program value, enable the serial interrupt.
 *
 ********************************************************************************/
_inline void		
ta_save_SFRs( void )		
{			 
	saveIE   =   IE;            /* Save IE                              		*/
	IE       = 0x90;            /* Disable all interrupts except serial 		*/
	saveIEN1 = IEN1;            /* Save IEN1                            		*/
	IEN1     =    0;            /* Disable all IEN1 related interrupts  		*/
}		

#endif/* _PCM812_H */		
